==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/XslTransformationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p383362_="https://jakarta.ee/xml/ns/jaxb" xmlns:p837822_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;This element defines one XSLT transformation and the resources and parameters necessary for it.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for XslTransformationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="XslTransformationType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="resources" type="{http://schema.webpdf.de/1.0/operation}XslTransformationResourcesType" minOccurs="0"/>
 *       </all>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "XslTransformationType", propOrder = {

})
public class XslTransformationType {

    protected XslTransformationResourcesType resources;

    /**
     * Gets the value of the resources property.
     * 
     * @return
     *     possible object is
     *     {@link XslTransformationResourcesType }
     *     
     */
    public XslTransformationResourcesType getResources() {
        return resources;
    }

    /**
     * Sets the value of the resources property.
     * 
     * @param value
     *     allowed object is
     *     {@link XslTransformationResourcesType }
     *     
     */
    public void setResources(XslTransformationResourcesType value) {
        this.resources = value;
    }

    public boolean isSetResources() {
        return (this.resources!= null);
    }

}

==> webpdf-wsclient-9.0.2-sources.jar: net/webpdf/wsclient/schema/operation/XslTransformationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p117921_="https://jakarta.ee/xml/ns/jaxb" xmlns:p71612_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;This element defines one XSLT transformation and the resources and parameters necessary for it.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for XslTransformationType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="XslTransformationType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="resources" type="{http://schema.webpdf.de/1.0/operation}XslTransformationResourcesType" minOccurs="0"/>
 *       </all>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "XslTransformationType", propOrder = {

})
public class XslTransformationType {

    protected XslTransformationResourcesType resources;

    /**
     * Gets the value of the resources property.
     * 
     * @return
     *     possible object is
     *     {@link XslTransformationResourcesType }
     *     
     */
    public XslTransformationResourcesType getResources() {
        return resources;
    }

    /**
     * Sets the value of the resources property.
     * 
     * @param value
     *     allowed object is
     *     {@link XslTransformationResourcesType }
     *     
     */
    public void setResources(XslTransformationResourcesType value) {
        this.resources = value;
    }

    public boolean isSetResources() {
        return (this.resources!= null);
    }

}
